@@ -11,7 +11,7 @@ import shutil
 
 # Where to insert example code.
 source_include_pattern = re.compile(
-  r'\s*<para><ulink url="&url_examples_base;([/\w]+)">Source Code</ulink></para>\s*(?:<!--\s*Insert\s+(.*?)-->)?')
+  r'\s*<para><link xlink:href="&url_examples_base;([/\w]+)">Source Code</link></para>\s*(?:<!--\s*Insert\s+(.*?)-->)?')
 
 # First line not part of leading comment in a source code file.
 # The comment typically consists of copyright and license text.
@@ -20,7 +20,7 @@ start_of_source_pattern = re.compile(r'[#\w]')
 def process_source_file(source_directory, source_basename, outfile, skip_leading_comments):
   found_start = not skip_leading_comments
   source_filename = os.path.join(source_directory, source_basename)
-  with open(source_filename, mode='r') as srcfile:
+  with open(source_filename, mode='r', encoding='utf-8', errors='surrogateescape') as srcfile:
     outfile.write('<para>File: <filename>' + source_basename + '</filename> (For use with gtkmm 4)</para>\n')
     outfile.write('<programlisting>\n<![CDATA[')
 
@@ -35,15 +35,19 @@ def process_source_file(source_directory, source_basename, outfile, skip_leading
     outfile.write(']]></programlisting>\n')
 
 def insert_example_code(examples_base_dir, input_xml_files, output_xml_file):
-  if not isinstance(input_xml_files, list):
-    input_xml_files = [input_xml_files]
+  if not (isinstance(input_xml_files, list) or isinstance(input_xml_files, tuple)):
+    input_xml_files = [] if input_xml_files == None else [input_xml_files]
 
-  with open(output_xml_file, mode='w') as outfile:
+  # Assume that all files are UTF-8 encoded.
+  # If illegal UTF-8 bytes in the range 0x80..0xff are encountered, they are
+  # replaced by Unicode Private Use characters in the range 0xdc80..0xdcff
+  # and restored to their original values when the file is rewritten.
+  with open(output_xml_file, mode='w', encoding='utf-8', errors='surrogateescape') as outfile:
     for input_xml_file in input_xml_files:
-      with open(input_xml_file, mode='r') as infile:
+      with open(input_xml_file, mode='r', encoding='utf-8', errors='surrogateescape') as infile:
         for line in infile:
           # Look for
-          # <para><ulink url="&url_examples_base;helloworld">Source Code</ulink></para> [<!-- Insert filenames... -->]
+          # <para><link xlink:href="&url_examples_base;helloworld">Source Code</link></para> [<!-- Insert filenames... -->]
           source_include_match = source_include_pattern.match(line)
           if not source_include_match:
             # Print the line without changes.
@@ -53,7 +57,7 @@ def insert_example_code(examples_base_dir, input_xml_files, output_xml_file):
             # url_examples_base is assumed to be a GitLab URL. The git branch is then
             # included in url_examples_base. No need to add it here.
             outfile.write(source_include_match.expand(
-              '<para><ulink url="&url_examples_base;\\1">Source Code</ulink></para>\n'))
+              '<para><link xlink:href="&url_examples_base;\\1">Source Code</link></para>\n'))
             outfile.write('<!-- start inserted example code -->\n')
 
             # List all the source files in the examples directory.
