@@ -22,8 +22,8 @@ ExampleWindow::ExampleWindow()
 {
   set_title("Gtk::Application example");
 
-  add(m_scrolledwindow);
-  m_scrolledwindow.add(m_view);
+  set_child(m_scrolledwindow);
+  m_scrolledwindow.set_child(m_view);
 }
 
 bool ExampleWindow::load_file(const Glib::RefPtr<Gio::File>& file)
