@@ -25,6 +25,7 @@ ExampleWindow::ExampleWindow()
   m_Button("Show AboutDialog")
 {
   set_title("Gtk::AboutDialog example");
+  set_default_size(400, 150);
 
   set_child(m_VBox);
 
@@ -44,8 +45,7 @@ ExampleWindow::ExampleWindow()
   m_Dialog.set_transient_for(*this);
   m_Dialog.set_hide_on_close();
 
-  m_Dialog.set_logo(Gdk::Texture::create_for_pixbuf(
-    Gdk::Pixbuf::create_from_resource("/about/gtkmm_logo.gif", -1, 40, true)));
+  m_Dialog.set_logo(Gdk::Texture::create_from_resource("/about/gtkmm_logo.gif"));
   m_Dialog.set_program_name("Example application");
   m_Dialog.set_version("1.0.0");
   m_Dialog.set_copyright("Murray Cumming");
