@@ -21,6 +21,5 @@ int main(int argc, char *argv[])
 {
   auto app = Gtk::Application::create("org.gtkmm.example");
 
-  ExampleWindow window;
-  return app->run(window, argc, argv); //Shows the window and returns when it is closed.
+  return app->make_window_and_run<ExampleWindow>(argc, argv); //Shows the window and returns when it is closed.
 }
